@@ -36,12 +36,14 @@
 #define MAX_NR_BNEP_SERVICES 1
 #define MAX_NR_BNEP_CHANNELS 1
 #define MAX_NR_HFP_CONNECTIONS 1
+#define MAX_NR_HID_HOST_CONNECTIONS 1
+#define MAX_NR_HIDS_CLIENTS 1
 #define MAX_NR_WHITELIST_ENTRIES 1
 #define MAX_NR_SM_LOOKUP_ENTRIES 3
 #define MAX_NR_SERVICE_RECORD_ITEMS 1
 #define MAX_NR_AVDTP_STREAM_ENDPOINTS 1
 #define MAX_NR_AVDTP_CONNECTIONS 1
-#define MAX_NR_AVRCP_CONNECTIONS 1
+#define MAX_NR_AVRCP_CONNECTIONS 2
 
 // Link Key DB and LE Device DB using TLV on top of Flash Sector interface
 #define NVM_NUM_LINK_KEYS 16
