@@ -232,9 +232,9 @@ static void setup_lc3_encoder(void){
     for (channel = 0 ; channel < num_bis ; channel++){
         btstack_lc3_encoder_google_t * context = &encoder_contexts[channel];
         lc3_encoder = btstack_lc3_encoder_google_init_instance(context);
-        lc3_encoder->configure(context, sampling_frequency_hz, frame_duration);
+        lc3_encoder->configure(context, sampling_frequency_hz, frame_duration, octets_per_frame);
     }
-    number_samples_per_frame = lc3_encoder->get_number_samples_per_frame(&encoder_contexts[0]);
+    number_samples_per_frame = btstack_lc3_samples_per_frame(sampling_frequency_hz, frame_duration);
     btstack_assert(number_samples_per_frame <= MAX_SAMPLES_PER_FRAME);
     printf("LC3 Encoder config: %u hz, frame duration %s ms, num samples %u, num octets %u\n",
            sampling_frequency_hz, frame_duration == BTSTACK_LC3_FRAME_DURATION_7500US ? "7.5" : "10",
@@ -258,9 +258,9 @@ static void setup_lc3_decoder(void){
                 lc3_decoder = btstack_lc3_decoder_google_init_instance(decoder_context);
             }
             decoder_contexts[channel] = decoder_context;
-            lc3_decoder->configure(decoder_context, sampling_frequency_hz, frame_duration);
+            lc3_decoder->configure(decoder_context, sampling_frequency_hz, frame_duration, octets_per_frame);
         }
-    number_samples_per_frame = lc3_decoder->get_number_samples_per_frame(decoder_contexts[0]);
+    number_samples_per_frame = btstack_lc3_samples_per_frame(sampling_frequency_hz, frame_duration);
     btstack_assert(number_samples_per_frame <= MAX_SAMPLES_PER_FRAME);
 }
 
@@ -332,7 +332,7 @@ static void test_encoder(){
 
         // encode frame
         uint8_t buffer[200];
-        lc3_encoder->encode_signed_16(&encoder_contexts[0], pcm, 1, buffer, octets_per_frame);
+        lc3_encoder->encode_signed_16(&encoder_contexts[0], pcm, 1, buffer);
         generated_samples += number_samples_per_frame;
         uint32_t block_encoded_ms  = btstack_run_loop_get_time_ms();
         plc_frame_counter++;
@@ -346,7 +346,7 @@ static void test_encoder(){
 
         // decode codec frame
         uint8_t tmp_BEC_detect;
-        (void) lc3_decoder->decode_signed_16(decoder_contexts[0], buffer, octets_per_frame, BFI, pcm, 1, &tmp_BEC_detect);
+        (void) lc3_decoder->decode_signed_16(decoder_contexts[0], buffer, BFI, pcm, 1, &tmp_BEC_detect);
 
         uint32_t block_decoded_ms  = btstack_run_loop_get_time_ms();
 
