@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -56,15 +56,6 @@
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure. */
-static const fsp_version_t g_motor_estimate_version =
-{
-    .api_version_major  = MOTOR_ANGLE_API_VERSION_MAJOR,
-    .api_version_minor  = MOTOR_ANGLE_API_VERSION_MINOR,
-    .code_version_major = MOTOR_ESTIMATE_CODE_VERSION_MAJOR,
-    .code_version_minor = MOTOR_ESTIMATE_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global variables
  **********************************************************************************************************************/
@@ -79,7 +70,12 @@ const motor_angle_api_t g_motor_angle_on_motor_estimate =
     .angleSpeedGet         = RM_MOTOR_ESTIMATE_AngleSpeedGet,
     .estimatedComponentGet = RM_MOTOR_ESTIMATE_EstimatedComponentGet,
     .parameterUpdate       = RM_MOTOR_ESTIMATE_ParameterUpdate,
-    .versionGet            = RM_MOTOR_ESTIMATE_VersionGet
+    .internalCalculate     = RM_MOTOR_ESTIMATE_InternalCalculate,
+    .angleAdjust           = RM_MOTOR_ESTIMATE_AngleAdjust,
+    .encoderCyclic         = RM_MOTOR_ESTIMATE_EncoderCyclic,
+    .infoGet               = RM_MOTOR_ESTIMATE_InfoGet,
+    .cyclicProcess         = RM_MOTOR_ESTIMATE_CyclicProcess,
+    .sensorDataSet         = RM_MOTOR_ESTIMATE_SensorDataSet,
 };
 
 /*******************************************************************************************************************//**
@@ -127,10 +123,8 @@ fsp_err_t RM_MOTOR_ESTIMATE_Open (motor_angle_ctrl_t * const p_ctrl, motor_angle
 
     rm_motor_estimate_bemf_obs_init(&(p_instance_ctrl->st_bemf_obs), &(p_extended_cfg->st_motor_params));
 
-    rm_motor_estimate_bemf_observer_gain_calc(&(p_extended_cfg->st_motor_params),
-                                              p_extended_cfg,
-                                              &(p_instance_ctrl->st_bemf_obs),
-                                              p_extended_cfg->f4_ctrl_period);
+    rm_motor_estimate_bemf_observer_gain_calc(&(p_extended_cfg->st_motor_params), p_extended_cfg,
+                                              &(p_instance_ctrl->st_bemf_obs), p_extended_cfg->f4_ctrl_period);
 
     rm_motor_estimate_speed_gain_calc(p_extended_cfg, &(p_instance_ctrl->st_pll_est), p_extended_cfg->f4_ctrl_period);
 
@@ -192,6 +186,7 @@ fsp_err_t RM_MOTOR_ESTIMATE_Reset (motor_angle_ctrl_t * const p_ctrl)
     rm_motor_estimate_speed_reset(&(p_instance_ctrl->st_pll_est));
     p_instance_ctrl->u1_flg_pi_ctrl   = MOTOR_ESTIMATE_FLG_CLR;
     p_instance_ctrl->u1_flg_pll_start = MOTOR_ESTIMATE_FLG_SET;
+    p_instance_ctrl->f4_angle_rad     = 0.0F;
 
     return err;
 }
@@ -341,8 +336,7 @@ fsp_err_t RM_MOTOR_ESTIMATE_AngleSpeedGet (motor_angle_ctrl_t * const p_ctrl,
             }
 
             /* Estimate angle and speed */
-            rm_motor_estimate_speed_pll(&(p_instance_ctrl->st_pll_est),
-                                        p_instance_ctrl->f4_phase_err_rad,
+            rm_motor_estimate_speed_pll(&(p_instance_ctrl->st_pll_est), p_instance_ctrl->f4_phase_err_rad,
                                         &(p_instance_ctrl->f4_speed_rad));
         }
         else
@@ -438,36 +432,129 @@ fsp_err_t RM_MOTOR_ESTIMATE_ParameterUpdate (motor_angle_ctrl_t * const p_ctrl,
     {
         p_instance_ctrl->p_cfg = p_cfg;
 
-        rm_motor_estimate_bemf_observer_gain_calc(&(p_extended_cfg->st_motor_params),
-                                                  p_extended_cfg,
-                                                  &(p_instance_ctrl->st_bemf_obs),
-                                                  p_extended_cfg->f4_ctrl_period);
+        rm_motor_estimate_bemf_observer_gain_calc(&(p_extended_cfg->st_motor_params), p_extended_cfg,
+                                                  &(p_instance_ctrl->st_bemf_obs), p_extended_cfg->f4_ctrl_period);
 
-        rm_motor_estimate_speed_gain_calc(p_extended_cfg,
-                                          &(p_instance_ctrl->st_pll_est),
+        rm_motor_estimate_speed_gain_calc(p_extended_cfg, &(p_instance_ctrl->st_pll_est),
                                           p_extended_cfg->f4_ctrl_period);
     }
 
     return err;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Return Motor Angle Estimation Middle module version. Implements @ref motor_angle_api_t::versionGet.
+/*******************************************************************************************************************//**
+ * @brief Calculate internal parameters. Implements @ref motor_angle_api_t::internalCalculate
  *
- * @retval      FSP_SUCCESS             Version information successfully read.
- * @retval      FSP_ERR_ASSERTION       Null pointer passed as a parameter
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ * @retval FSP_ERR_ASSERTION        Null pointer.
+ * @retval FSP_ERR_NOT_OPEN         Module is not open.
  **********************************************************************************************************************/
-fsp_err_t RM_MOTOR_ESTIMATE_VersionGet (fsp_version_t * const p_version)
+fsp_err_t RM_MOTOR_ESTIMATE_InternalCalculate (motor_angle_ctrl_t * const p_ctrl)
 {
-#if (MOTOR_ESTIMATE_CFG_PARAM_CHECKING_ENABLE)
+    fsp_err_t err = FSP_ERR_UNSUPPORTED;
 
-    /* Verify parameters are valid */
-    FSP_ASSERT(p_version != NULL);
+#if (MOTOR_ESTIMATE_CFG_PARAM_CHECKING_ENABLE)
+    motor_estimate_instance_ctrl_t * p_instance_ctrl = (motor_estimate_instance_ctrl_t *) p_ctrl;
+    FSP_ASSERT(p_instance_ctrl != NULL);
+    FSP_ERROR_RETURN(MOTOR_ESTIMATE_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
+#else
+    FSP_PARAMETER_NOT_USED(p_ctrl);
 #endif
 
-    p_version->version_id = g_motor_estimate_version.version_id;
+    return err;
+}
 
-    return FSP_SUCCESS;
+/*******************************************************************************************************************//**
+ * @brief Angle Adjustment Process. Implements @ref motor_angle_api_t::angleAdjust
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ * @retval FSP_ERR_ASSERTION        Null pointer.
+ * @retval FSP_ERR_NOT_OPEN         Module is not open.
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_ESTIMATE_AngleAdjust (motor_angle_ctrl_t * const p_ctrl)
+{
+    fsp_err_t err = FSP_ERR_UNSUPPORTED;
+
+#if (MOTOR_ESTIMATE_CFG_PARAM_CHECKING_ENABLE)
+    motor_estimate_instance_ctrl_t * p_instance_ctrl = (motor_estimate_instance_ctrl_t *) p_ctrl;
+    FSP_ASSERT(p_instance_ctrl != NULL);
+    FSP_ERROR_RETURN(MOTOR_ESTIMATE_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
+#else
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+#endif
+
+    return err;
+}
+
+/*******************************************************************************************************************//**
+ * @brief Encoder Cyclic Process (Call in cyclic timer). Implements @ref motor_angle_api_t::encoderCyclic
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ * @retval FSP_ERR_ASSERTION        Null pointer.
+ * @retval FSP_ERR_NOT_OPEN         Module is not open.
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_ESTIMATE_EncoderCyclic (motor_angle_ctrl_t * const p_ctrl)
+{
+    fsp_err_t err = FSP_ERR_UNSUPPORTED;
+
+#if (MOTOR_ESTIMATE_CFG_PARAM_CHECKING_ENABLE)
+    motor_estimate_instance_ctrl_t * p_instance_ctrl = (motor_estimate_instance_ctrl_t *) p_ctrl;
+    FSP_ASSERT(p_instance_ctrl != NULL);
+    FSP_ERROR_RETURN(MOTOR_ESTIMATE_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
+#else
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+#endif
+
+    return err;
+}
+
+/*******************************************************************************************************************//**
+ * @brief Gets information of Encoder Angle Module. Implements @ref motor_angle_api_t::infoGet
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ * @retval FSP_ERR_ASSERTION        Null pointer.
+ * @retval FSP_ERR_NOT_OPEN         Module is not open.
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_ESTIMATE_InfoGet (motor_angle_ctrl_t * const p_ctrl, motor_angle_encoder_info_t * const p_info)
+{
+    fsp_err_t err = FSP_ERR_UNSUPPORTED;
+
+#if (MOTOR_ESTIMATE_CFG_PARAM_CHECKING_ENABLE)
+    motor_estimate_instance_ctrl_t * p_instance_ctrl = (motor_estimate_instance_ctrl_t *) p_ctrl;
+    FSP_ASSERT(p_instance_ctrl != NULL);
+    FSP_ASSERT(p_info != NULL);
+    FSP_ERROR_RETURN(MOTOR_ESTIMATE_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
+#else
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+#endif
+    FSP_PARAMETER_NOT_USED(p_info);
+
+    return err;
+}
+
+/*******************************************************************************************************************//**
+ * @brief Perform induction cyclic process. Implements @ref motor_angle_api_t::cyclicProcess
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_ESTIMATE_CyclicProcess (motor_angle_ctrl_t * const p_ctrl)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+
+    return FSP_ERR_UNSUPPORTED;
+}
+
+/*******************************************************************************************************************//**
+ * @brief Set sensor data. Implements @ref motor_angle_api_t::sensorDataSet
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_ESTIMATE_SensorDataSet (motor_angle_ctrl_t * const p_ctrl, motor_angle_ad_data_t * const p_ad_data)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(p_ad_data);
+
+    return FSP_ERR_UNSUPPORTED;
 }
 
 /*******************************************************************************************************************//**
