@@ -1,5 +1,5 @@
 /***********************************************************************************************************************
- * Copyright [2020-2021] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
+ * Copyright [2020-2023] Renesas Electronics Corporation and/or its affiliates.  All Rights Reserved.
  *
  * This software and documentation are supplied by Renesas Electronics America Inc. and may only be used with products
  * of Renesas Electronics Corp. and its affiliates ("Renesas").  No other uses are authorized.  Renesas products are
@@ -37,7 +37,7 @@
 #define MOTOR_SENSORLESS_FLG_CLR                               (0)
 #define MOTOR_SENSORLESS_FLG_SET                               (1)
 
-/* For Statemachine */
+/* For statemachine */
 #define MOTOR_SENSORLESS_STATEMACHINE_SIZE_STATE               (3)
 #define MOTOR_SENSORLESS_STATEMACHINE_SIZE_EVENT               (4)
 
@@ -60,7 +60,7 @@
  * Private function prototypes
  **********************************************************************************************************************/
 
-/* Speed Control <=> Current Control Interface functions */
+/* Speed control <=> Current control interface functions */
 void rm_motor_sensorless_current_callback(motor_current_callback_args_t * p_args);
 void rm_motor_sensorless_speed_callback(motor_speed_callback_args_t * p_args);
 
@@ -77,7 +77,7 @@ static void rm_motor_sensorless_copy_speed_current(motor_speed_output_t  * st_ou
 static void rm_motor_sensorless_copy_current_speed(motor_current_output_t * st_output,
                                                    motor_speed_input_t    * st_input);
 
-/* action functions */
+/* Action functions */
 static uint8_t rm_motor_sensorless_active(motor_sensorless_instance_ctrl_t * p_ctrl);
 static uint8_t rm_motor_sensorless_inactive(motor_sensorless_instance_ctrl_t * p_ctrl);
 static uint8_t rm_motor_sensorless_reset(motor_sensorless_instance_ctrl_t * p_ctrl);
@@ -115,7 +115,7 @@ static const motor_sensorless_action_t motor_sensorless_action_table[MOTOR_SENSO
 /* 3:EVENT_RESET    */ {rm_motor_sensorless_reset,    rm_motor_sensorless_error,    rm_motor_sensorless_reset       },
 };
 
-/* statemachine functions */
+/* Statemachine functions */
 static void     rm_motor_sensorless_statemachine_init(motor_sensorless_statemachine_t * p_state_machine);
 static void     rm_motor_sensorless_statemachine_reset(motor_sensorless_statemachine_t * p_state_machine);
 static uint16_t rm_motor_sensorless_statemachine_event(motor_sensorless_instance_ctrl_t * p_ctrl,
@@ -125,32 +125,25 @@ static uint16_t rm_motor_sensorless_statemachine_event(motor_sensorless_instance
  * Private global variables
  **********************************************************************************************************************/
 
-/* Version data structure. */
-static const fsp_version_t g_motor_sensorless_version =
-{
-    .api_version_major  = MOTOR_API_VERSION_MAJOR,
-    .api_version_minor  = MOTOR_API_VERSION_MINOR,
-    .code_version_major = MOTOR_SENSORLESS_CODE_VERSION_MAJOR,
-    .code_version_minor = MOTOR_SENSORLESS_CODE_VERSION_MINOR
-};
-
 /***********************************************************************************************************************
  * Global variables
  **********************************************************************************************************************/
 const motor_api_t g_motor_on_sensorless =
 {
-    .open       = RM_MOTOR_SENSORLESS_Open,
-    .close      = RM_MOTOR_SENSORLESS_Close,
-    .run        = RM_MOTOR_SENSORLESS_Run,
-    .stop       = RM_MOTOR_SENSORLESS_Stop,
-    .reset      = RM_MOTOR_SENSORLESS_Reset,
-    .errorSet   = RM_MOTOR_SENSORLESS_ErrorSet,
-    .speedSet   = RM_MOTOR_SENSORLESS_SpeedSet,
-    .statusGet  = RM_MOTOR_SENSORLESS_StatusGet,
-    .angleGet   = RM_MOTOR_SENSORLESS_AngleGet,
-    .speedGet   = RM_MOTOR_SENSORLESS_SpeedGet,
-    .errorCheck = RM_MOTOR_SENSORLESS_ErrorCheck,
-    .versionGet = RM_MOTOR_SENSORLESS_VersionGet,
+    .open            = RM_MOTOR_SENSORLESS_Open,
+    .close           = RM_MOTOR_SENSORLESS_Close,
+    .run             = RM_MOTOR_SENSORLESS_Run,
+    .stop            = RM_MOTOR_SENSORLESS_Stop,
+    .reset           = RM_MOTOR_SENSORLESS_Reset,
+    .errorSet        = RM_MOTOR_SENSORLESS_ErrorSet,
+    .speedSet        = RM_MOTOR_SENSORLESS_SpeedSet,
+    .statusGet       = RM_MOTOR_SENSORLESS_StatusGet,
+    .angleGet        = RM_MOTOR_SENSORLESS_AngleGet,
+    .speedGet        = RM_MOTOR_SENSORLESS_SpeedGet,
+    .errorCheck      = RM_MOTOR_SENSORLESS_ErrorCheck,
+    .positionSet     = RM_MOTOR_SENSORLESS_PositionSet,
+    .waitStopFlagGet = RM_MOTOR_SENSORLESS_WaitStopFlagGet,
+    .functionSelect  = RM_MOTOR_SENSORLESS_FunctionSelect,
 };
 
 /*******************************************************************************************************************//**
@@ -189,7 +182,7 @@ fsp_err_t RM_MOTOR_SENSORLESS_Open (motor_ctrl_t * const p_ctrl, motor_cfg_t con
     FSP_ASSERT(NULL != p_cfg);
     MOTOR_SENSORLESS_ERROR_RETURN(MOTOR_SENSORLESS_OPEN != p_instance_ctrl->open, FSP_ERR_ALREADY_OPEN);
 
-    /* using modules' instance check */
+    /* Using modules' instance check */
     MOTOR_SENSORLESS_ERROR_RETURN(NULL != p_cfg->p_motor_speed_instance, FSP_ERR_ASSERTION);
     MOTOR_SENSORLESS_ERROR_RETURN(NULL != p_cfg->p_motor_current_instance, FSP_ERR_ASSERTION);
 
@@ -203,12 +196,12 @@ fsp_err_t RM_MOTOR_SENSORLESS_Open (motor_ctrl_t * const p_ctrl, motor_cfg_t con
     MOTOR_SENSORLESS_ERROR_RETURN(p_extended_cfg->f_lowvoltage_limit >= 0.0F, FSP_ERR_INVALID_ARGUMENT);
 #endif
 
-    p_cfg->p_motor_speed_instance->p_api->open(p_cfg->p_motor_speed_instance->p_ctrl,
-                                               p_cfg->p_motor_speed_instance->p_cfg);
-
     p_cfg->p_motor_current_instance->p_api->open(p_cfg->p_motor_current_instance->p_ctrl,
                                                  p_cfg->p_motor_current_instance->p_cfg);
 
+    p_cfg->p_motor_speed_instance->p_api->open(p_cfg->p_motor_speed_instance->p_ctrl,
+                                               p_cfg->p_motor_speed_instance->p_cfg);
+
     p_instance_ctrl->p_cfg = p_cfg;
 
     p_instance_ctrl->u2_error_info = MOTOR_ERROR_NONE;
@@ -246,14 +239,13 @@ fsp_err_t RM_MOTOR_SENSORLESS_Close (motor_ctrl_t * const p_ctrl)
     FSP_ASSERT(NULL != p_instance_ctrl);
     MOTOR_SENSORLESS_ERROR_RETURN(MOTOR_SENSORLESS_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
 
-    /* using modules' instance check */
+    /* Using modules' instance check */
     MOTOR_SENSORLESS_ERROR_RETURN(NULL != p_instance_ctrl->p_cfg->p_motor_speed_instance, FSP_ERR_ASSERTION);
     MOTOR_SENSORLESS_ERROR_RETURN(NULL != p_instance_ctrl->p_cfg->p_motor_current_instance, FSP_ERR_ASSERTION);
 #endif
 
-    /* close using modules */
-    p_instance_ctrl->p_cfg->p_motor_speed_instance->p_api->close(
-        p_instance_ctrl->p_cfg->p_motor_speed_instance->p_ctrl);
+    /* Close using modules */
+    p_instance_ctrl->p_cfg->p_motor_speed_instance->p_api->close(p_instance_ctrl->p_cfg->p_motor_speed_instance->p_ctrl);
 
     p_instance_ctrl->p_cfg->p_motor_current_instance->p_api->close(
         p_instance_ctrl->p_cfg->p_motor_current_instance->p_ctrl);
@@ -289,7 +281,7 @@ fsp_err_t RM_MOTOR_SENSORLESS_Reset (motor_ctrl_t * const p_ctrl)
     MOTOR_SENSORLESS_ERROR_RETURN(MOTOR_SENSORLESS_OPEN == p_instance_ctrl->open, FSP_ERR_NOT_OPEN);
 #endif
 
-    /* Reset is valid only at "ERROR" status */
+    /* Reset is valid only at "error" status */
     if (MOTOR_ERROR_NONE != p_instance_ctrl->u2_error_info)
     {
         rm_motor_sensorless_statemachine_event(p_instance_ctrl, MOTOR_SENSORLESS_CTRL_EVENT_RESET);
@@ -297,7 +289,7 @@ fsp_err_t RM_MOTOR_SENSORLESS_Reset (motor_ctrl_t * const p_ctrl)
         rm_motor_sensorless_init_speed_input(&(p_instance_ctrl->st_speed_input));
         rm_motor_sensorless_init_speed_output(&(p_instance_ctrl->st_speed_output));
 
-        /* clear error info */
+        /* Clear error information */
         p_instance_ctrl->u2_error_info = MOTOR_ERROR_NONE;
     }
 
@@ -606,21 +598,53 @@ fsp_err_t RM_MOTOR_SENSORLESS_ErrorCheck (motor_ctrl_t * const p_ctrl, uint16_t
     return err;
 }
 
-/***********************************************************************************************************************
- * DEPRECATED Return MOTOR Sensorless driver version. Implements @ref motor_api_t::versionGet.
+/*******************************************************************************************************************//**
+ * @brief Set position reference. Implements @ref motor_api_t::positionSet.
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ *
+ * @note
  *
- * @retval      FSP_SUCCESS             Version information successfully read.
- * @retval      FSP_ERR_ASSERTION       Null pointer passed as a parameter
  **********************************************************************************************************************/
-fsp_err_t RM_MOTOR_SENSORLESS_VersionGet (fsp_version_t * const p_version)
+fsp_err_t RM_MOTOR_SENSORLESS_PositionSet (motor_ctrl_t * const                      p_ctrl,
+                                           motor_speed_position_data_t const * const p_position)
 {
-#if MOTOR_SENSORLESS_CFG_PARAM_CHECKING_ENABLE
-    FSP_ASSERT(NULL != p_version);
-#endif
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(p_position);
 
-    p_version->version_id = g_motor_sensorless_version.version_id;
+    return FSP_ERR_UNSUPPORTED;
+}
 
-    return FSP_SUCCESS;
+/*******************************************************************************************************************//**
+ * @brief Get wait stop flag. Implements @ref motor_api_t::waitStopFlagGet.
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ *
+ * @note
+ *
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_SENSORLESS_WaitStopFlagGet (motor_ctrl_t * const p_ctrl, motor_wait_stop_flag_t * const p_flag)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(p_flag);
+
+    return FSP_ERR_UNSUPPORTED;
+}
+
+/*******************************************************************************************************************//**
+ * @brief Select function. Implements @ref motor_api_t::functionSelect.
+ *
+ * @retval FSP_ERR_UNSUPPORTED      Unsupported.
+ *
+ * @note
+ *
+ **********************************************************************************************************************/
+fsp_err_t RM_MOTOR_SENSORLESS_FunctionSelect (motor_ctrl_t * const p_ctrl, motor_function_select_t const function)
+{
+    FSP_PARAMETER_NOT_USED(p_ctrl);
+    FSP_PARAMETER_NOT_USED(function);
+
+    return FSP_ERR_UNSUPPORTED;
 }
 
 /*******************************************************************************************************************//**
@@ -628,10 +652,10 @@ fsp_err_t RM_MOTOR_SENSORLESS_VersionGet (fsp_version_t * const p_version)
  **********************************************************************************************************************/
 
 /***********************************************************************************************************************
- * Private Functions
+ * Private functions
  **********************************************************************************************************************/
 
-/*****  For Status Transition *****/
+/*****  For status transition *****/
 
 /***********************************************************************************************************************
  * Function Name : rm_motor_sensorless_active
@@ -685,10 +709,9 @@ static uint8_t rm_motor_sensorless_inactive (motor_sensorless_instance_ctrl_t *
  **********************************************************************************************************************/
 static uint8_t rm_motor_sensorless_nowork (motor_sensorless_instance_ctrl_t * p_ctrl)
 {
-    /* Do Nothing */
-
     if (p_ctrl->p_cfg->p_motor_speed_instance != NULL)
     {
+        /* Do nothing */
     }
 
     return 0;
@@ -812,7 +835,7 @@ static uint16_t rm_motor_sensorless_statemachine_event (motor_sensorless_instanc
     func_action = motor_sensorless_action_table[u1_event][p_ctrl->st_statem.u1_status];
     action_ret  = func_action(p_ctrl);
 
-    /* If return value is not zero, set the Action Exception flag */
+    /* If return value is not zero, set the action exception flag */
     if (action_ret != 0U)
     {
         p_ctrl->st_statem.u2_error_status |= MOTOR_SENSORLESS_STATEMACHINE_ERROR_ACTIONEXCEPTION;
@@ -823,24 +846,22 @@ static uint16_t rm_motor_sensorless_statemachine_event (motor_sensorless_instanc
     return p_ctrl->st_statem.u2_error_status;
 }                                      /* End of function rm_motor_sensorless_statemachine_event */
 
-/*****  For Status Transition *****/
-
 /***********************************************************************************************************************
  * Function Name : rm_motor_check_over_speed_error
  * Description   : Checks over-speed error
- * Arguments     : f4_speed_rad - The electrical speed[rad/s]
- *                 f4_speed_limit_rad - The speed[rad/s] threshold of the over-speed error, should be a positive value
+ * Arguments     : f4_speed - The electrical speed
+ *                 f4_speed_limit - The speed threshold of the over-speed error, should be a positive value
  * Return Value  : The over-speed error flag
  **********************************************************************************************************************/
-static inline uint16_t rm_motor_check_over_speed_error (float f4_speed_rad, float f4_speed_limit_rad)
+static inline uint16_t rm_motor_check_over_speed_error (float f4_speed, float f4_speed_limit)
 {
     float    f4_temp0;
     uint16_t u2_temp0;
 
     u2_temp0 = MOTOR_ERROR_NONE;
 
-    f4_temp0 = fabsf(f4_speed_rad);
-    if (f4_temp0 > f4_speed_limit_rad)
+    f4_temp0 = fabsf(f4_speed);
+    if (f4_temp0 > f4_speed_limit)
     {
         u2_temp0 = MOTOR_ERROR_OVER_SPEED;
     }
@@ -953,24 +974,16 @@ static uint16_t rm_motor_sensorless_error_check (motor_sensorless_instance_ctrl_
     uint16_t u2_error_flags = 0U;
     motor_sensorless_extended_cfg_t * p_extended_cfg = (motor_sensorless_extended_cfg_t *) p_ctrl->p_cfg->p_extend;
 
-    /*==================================*/
-    /*     Over current error check     */
-    /*==================================*/
+    /* Over current error check */
     u2_error_flags |= rm_motor_check_over_current_error(f_iu, f_iv, f_iw, p_extended_cfg->f_overcurrent_limit);
 
-    /*==================================*/
-    /*     Over voltage error check     */
-    /*==================================*/
+    /* Over voltage error check */
     u2_error_flags |= rm_motor_check_over_voltage_error(f_vdc, p_extended_cfg->f_overvoltage_limit);
 
-    /*==================================*/
-    /*     Low voltage error check      */
-    /*==================================*/
+    /* Low voltage error check */
     u2_error_flags |= rm_motor_check_low_voltage_error(f_vdc, p_extended_cfg->f_lowvoltage_limit);
 
-    /*================================*/
-    /* Over speed error check     */
-    /*================================*/
+    /* Over speed error check */
     u2_error_flags |= rm_motor_check_over_speed_error(f_speed, p_extended_cfg->f_overspeed_limit);
 
     return u2_error_flags;
@@ -1046,7 +1059,7 @@ static void rm_motor_sensorless_copy_current_speed (motor_current_output_t * st_
     st_input->u1_flag_get_iref = st_output->u1_flag_get_iref;
 }                                      /* End of function rm_motor_sensorless_copy_current_speed() */
 
-/*****  Callback Function *****/
+/*****  Callback function *****/
 
 /***********************************************************************************************************************
  * Function Name : rm_motor_sensorless_current_callback
@@ -1056,21 +1069,20 @@ static void rm_motor_sensorless_copy_current_speed (motor_current_output_t * st_
  **********************************************************************************************************************/
 void rm_motor_sensorless_current_callback (motor_current_callback_args_t * p_args)
 {
-    motor_instance_t                      * p_instance = (motor_instance_t *) p_args->p_context;
-    motor_sensorless_instance_ctrl_t      * p_ctrl     = (motor_sensorless_instance_ctrl_t *) p_instance->p_ctrl;
-    motor_sensorless_extended_cfg_t const * p_extend   = p_ctrl->p_cfg->p_extend;
-    motor_sensorless_callback_args_t        temp_args_t;
+    motor_instance_t                 * p_instance = (motor_instance_t *) p_args->p_context;
+    motor_sensorless_instance_ctrl_t * p_ctrl     = (motor_sensorless_instance_ctrl_t *) p_instance->p_ctrl;
+    motor_callback_args_t              temp_args_t;
 
     switch (p_args->event)
     {
         case MOTOR_CURRENT_EVENT_FORWARD:
         {
             /* Invoke the callback function if it is set. */
-            if (NULL != p_extend->p_callback)
+            if (NULL != p_ctrl->p_cfg->p_callback)
             {
-                temp_args_t.event     = MOTOR_SENSORLESS_CALLBACK_EVENT_CURRENT_FORWARD;
-                temp_args_t.p_context = p_extend->p_context;
-                (p_extend->p_callback)(&temp_args_t);
+                temp_args_t.event     = MOTOR_CALLBACK_EVENT_CURRENT_FORWARD;
+                temp_args_t.p_context = p_ctrl->p_cfg->p_context;
+                (p_ctrl->p_cfg->p_callback)(&temp_args_t);
             }
 
             break;
@@ -1088,11 +1100,11 @@ void rm_motor_sensorless_current_callback (motor_current_callback_args_t * p_arg
         case MOTOR_CURRENT_EVENT_BACKWARD:
         {
             /* Invoke the callback function if it is set. */
-            if (NULL != p_extend->p_callback)
+            if (NULL != p_ctrl->p_cfg->p_callback)
             {
-                temp_args_t.event     = MOTOR_SENSORLESS_CALLBACK_EVENT_CURRENT_BACKWARD;
-                temp_args_t.p_context = p_extend->p_context;
-                (p_extend->p_callback)(&temp_args_t);
+                temp_args_t.event     = MOTOR_CALLBACK_EVENT_CURRENT_BACKWARD;
+                temp_args_t.p_context = p_ctrl->p_cfg->p_context;
+                (p_ctrl->p_cfg->p_callback)(&temp_args_t);
             }
 
             break;
@@ -1113,10 +1125,9 @@ void rm_motor_sensorless_current_callback (motor_current_callback_args_t * p_arg
  **********************************************************************************************************************/
 void rm_motor_sensorless_speed_callback (motor_speed_callback_args_t * p_args)
 {
-    motor_instance_t                      * p_instance = (motor_instance_t *) p_args->p_context;
-    motor_sensorless_instance_ctrl_t      * p_ctrl     = (motor_sensorless_instance_ctrl_t *) p_instance->p_ctrl;
-    motor_sensorless_extended_cfg_t const * p_extend   = p_ctrl->p_cfg->p_extend;
-    motor_sensorless_callback_args_t        temp_args_t;
+    motor_instance_t                 * p_instance = (motor_instance_t *) p_args->p_context;
+    motor_sensorless_instance_ctrl_t * p_ctrl     = (motor_sensorless_instance_ctrl_t *) p_instance->p_ctrl;
+    motor_callback_args_t              temp_args_t;
 
     switch (p_args->event)
     {
@@ -1129,11 +1140,11 @@ void rm_motor_sensorless_speed_callback (motor_speed_callback_args_t * p_args)
             rm_motor_sensorless_copy_current_speed(&(p_ctrl->st_current_output), &(p_ctrl->st_speed_input));
 
             /* Invoke the callback function if it is set. */
-            if (NULL != p_extend->p_callback)
+            if (NULL != p_ctrl->p_cfg->p_callback)
             {
-                temp_args_t.event     = MOTOR_SENSORLESS_CALLBACK_EVENT_SPEED_FORWARD;
-                temp_args_t.p_context = p_extend->p_context;
-                (p_extend->p_callback)(&temp_args_t);
+                temp_args_t.event     = MOTOR_CALLBACK_EVENT_SPEED_FORWARD;
+                temp_args_t.p_context = p_ctrl->p_cfg->p_context;
+                (p_ctrl->p_cfg->p_callback)(&temp_args_t);
             }
 
             break;
@@ -1142,11 +1153,11 @@ void rm_motor_sensorless_speed_callback (motor_speed_callback_args_t * p_args)
         case MOTOR_SPEED_EVENT_BACKWARD:
         {
             /* Invoke the callback function if it is set. */
-            if (NULL != p_extend->p_callback)
+            if (NULL != p_ctrl->p_cfg->p_callback)
             {
-                temp_args_t.event     = MOTOR_SENSORLESS_CALLBACK_EVENT_SPEED_BACKWARD;
-                temp_args_t.p_context = p_extend->p_context;
-                (p_extend->p_callback)(&temp_args_t);
+                temp_args_t.event     = MOTOR_CALLBACK_EVENT_SPEED_BACKWARD;
+                temp_args_t.p_context = p_ctrl->p_cfg->p_context;
+                (p_ctrl->p_cfg->p_callback)(&temp_args_t);
             }
 
             break;
