@@ -1,6 +1,6 @@
-import usocket as socket
-import ustruct as struct
-from ubinascii import hexlify
+import socket
+import struct
+from binascii import hexlify
 
 
 class MQTTException(Exception):
