@@ -61,8 +61,8 @@ typedef struct _pin_irq_obj_t {
     uint16_t phys_port;
 } pin_irq_obj_t;
 
-STATIC void pin_intr_handler_part1(void *arg);
-STATIC void pin_intr_handler_part2(uint32_t status);
+static void pin_intr_handler_part1(void *arg);
+static void pin_intr_handler_part2(uint32_t status);
 
 const pyb_pin_obj_t pyb_pin_obj[16 + 1] = {
     {{&pyb_pin_type}, 0, FUNC_GPIO0, PERIPHS_IO_MUX_GPIO0_U},
@@ -89,7 +89,7 @@ const pyb_pin_obj_t pyb_pin_obj[16 + 1] = {
 uint8_t pin_mode[16 + 1];
 
 // forward declaration
-STATIC const pin_irq_obj_t pin_irq_obj[16];
+static const pin_irq_obj_t pin_irq_obj[16];
 
 void pin_init0(void) {
     ETS_GPIO_INTR_DISABLE();
@@ -122,11 +122,22 @@ void MP_FASTCODE(pin_intr_handler_part2)(uint32_t status) {
 }
 
 pyb_pin_obj_t *mp_obj_get_pin_obj(mp_obj_t pin_in) {
-    if (mp_obj_get_type(pin_in) != &pyb_pin_type) {
-        mp_raise_ValueError(MP_ERROR_TEXT("expecting a pin"));
+    if (mp_obj_is_type(pin_in, &pyb_pin_type)) {
+        return pin_in;
     }
-    pyb_pin_obj_t *self = pin_in;
-    return self;
+    // Get the wanted pin object.
+    if (mp_obj_is_small_int(pin_in)) {
+        int wanted_pin = mp_obj_get_int(pin_in);
+        if (0 <= wanted_pin && wanted_pin < MP_ARRAY_SIZE(pyb_pin_obj)) {
+            pyb_pin_obj_t *pin = (pyb_pin_obj_t *)&pyb_pin_obj[wanted_pin];
+            if (pin->base.type != NULL) {
+                return pin;
+            }
+        }
+    }
+    // At this place a check for named pins may be added.
+    //
+    mp_raise_ValueError(MP_ERROR_TEXT("invalid pin"));
 }
 
 uint mp_obj_get_pin(mp_obj_t pin_in) {
@@ -231,7 +242,7 @@ void pin_set(uint pin, int value) {
     }
 }
 
-STATIC void pyb_pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void pyb_pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     pyb_pin_obj_t *self = self_in;
 
     // pin name
@@ -239,7 +250,7 @@ STATIC void pyb_pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_ki
 }
 
 // pin.init(mode, pull=None, *, value)
-STATIC mp_obj_t pyb_pin_obj_init_helper(pyb_pin_obj_t *self, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pyb_pin_obj_init_helper(pyb_pin_obj_t *self, size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum { ARG_mode, ARG_pull, ARG_value };
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_mode, MP_ARG_REQUIRED | MP_ARG_INT },
@@ -310,14 +321,7 @@ mp_obj_t mp_pin_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw,
     mp_arg_check_num(n_args, n_kw, 1, MP_OBJ_FUN_ARGS_MAX, true);
 
     // get the wanted pin object
-    int wanted_pin = mp_obj_get_int(args[0]);
-    pyb_pin_obj_t *pin = NULL;
-    if (0 <= wanted_pin && wanted_pin < MP_ARRAY_SIZE(pyb_pin_obj)) {
-        pin = (pyb_pin_obj_t *)&pyb_pin_obj[wanted_pin];
-    }
-    if (pin == NULL || pin->base.type == NULL) {
-        mp_raise_ValueError(MP_ERROR_TEXT("invalid pin"));
-    }
+    pyb_pin_obj_t *pin = mp_obj_get_pin_obj(args[0]);
 
     if (n_args > 1 || n_kw > 0) {
         // pin mode given, so configure this GPIO
@@ -330,7 +334,7 @@ mp_obj_t mp_pin_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw,
 }
 
 // fast method for getting/setting pin value
-STATIC mp_obj_t pyb_pin_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t pyb_pin_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 0, 1, false);
     pyb_pin_obj_t *self = self_in;
     if (n_args == 0) {
@@ -344,33 +348,33 @@ STATIC mp_obj_t pyb_pin_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const
 }
 
 // pin.init(mode, pull)
-STATIC mp_obj_t pyb_pin_obj_init(size_t n_args, const mp_obj_t *args, mp_map_t *kw_args) {
+static mp_obj_t pyb_pin_obj_init(size_t n_args, const mp_obj_t *args, mp_map_t *kw_args) {
     return pyb_pin_obj_init_helper(args[0], n_args - 1, args + 1, kw_args);
 }
 MP_DEFINE_CONST_FUN_OBJ_KW(pyb_pin_init_obj, 1, pyb_pin_obj_init);
 
 // pin.value([value])
-STATIC mp_obj_t pyb_pin_value(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t pyb_pin_value(size_t n_args, const mp_obj_t *args) {
     return pyb_pin_call(args[0], n_args - 1, 0, args + 1);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pyb_pin_value_obj, 1, 2, pyb_pin_value);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pyb_pin_value_obj, 1, 2, pyb_pin_value);
 
-STATIC mp_obj_t pyb_pin_off(mp_obj_t self_in) {
+static mp_obj_t pyb_pin_off(mp_obj_t self_in) {
     pyb_pin_obj_t *self = self_in;
     pin_set(self->phys_port, 0);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_pin_off_obj, pyb_pin_off);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_pin_off_obj, pyb_pin_off);
 
-STATIC mp_obj_t pyb_pin_on(mp_obj_t self_in) {
+static mp_obj_t pyb_pin_on(mp_obj_t self_in) {
     pyb_pin_obj_t *self = self_in;
     pin_set(self->phys_port, 1);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_pin_on_obj, pyb_pin_on);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_pin_on_obj, pyb_pin_on);
 
 // pin.irq(handler=None, trigger=IRQ_FALLING|IRQ_RISING, hard=False)
-STATIC mp_obj_t pyb_pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pyb_pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum { ARG_handler, ARG_trigger, ARG_hard };
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_handler, MP_ARG_OBJ, {.u_obj = mp_const_none} },
@@ -406,10 +410,10 @@ STATIC mp_obj_t pyb_pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *k
     // return the irq object
     return MP_OBJ_FROM_PTR(&pin_irq_obj[self->phys_port]);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(pyb_pin_irq_obj, 1, pyb_pin_irq);
+static MP_DEFINE_CONST_FUN_OBJ_KW(pyb_pin_irq_obj, 1, pyb_pin_irq);
 
-STATIC mp_uint_t pin_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode);
-STATIC mp_uint_t pin_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode) {
+static mp_uint_t pin_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode);
+static mp_uint_t pin_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, int *errcode) {
     (void)errcode;
     pyb_pin_obj_t *self = self_in;
 
@@ -425,7 +429,7 @@ STATIC mp_uint_t pin_ioctl(mp_obj_t self_in, mp_uint_t request, uintptr_t arg, i
     return -1;
 }
 
-STATIC const mp_rom_map_elem_t pyb_pin_locals_dict_table[] = {
+static const mp_rom_map_elem_t pyb_pin_locals_dict_table[] = {
     // instance methods
     { MP_ROM_QSTR(MP_QSTR_init),    MP_ROM_PTR(&pyb_pin_init_obj) },
     { MP_ROM_QSTR(MP_QSTR_value),   MP_ROM_PTR(&pyb_pin_value_obj) },
@@ -445,9 +449,9 @@ STATIC const mp_rom_map_elem_t pyb_pin_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_IRQ_FALLING), MP_ROM_INT(GPIO_PIN_INTR_NEGEDGE) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(pyb_pin_locals_dict, pyb_pin_locals_dict_table);
+static MP_DEFINE_CONST_DICT(pyb_pin_locals_dict, pyb_pin_locals_dict_table);
 
-STATIC const mp_pin_p_t pin_pin_p = {
+static const mp_pin_p_t pin_pin_p = {
     .ioctl = pin_ioctl,
 };
 
@@ -465,9 +469,9 @@ MP_DEFINE_CONST_OBJ_TYPE(
 /******************************************************************************/
 // Pin IRQ object
 
-STATIC const mp_obj_type_t pin_irq_type;
+static const mp_obj_type_t pin_irq_type;
 
-STATIC const pin_irq_obj_t pin_irq_obj[16] = {
+static const pin_irq_obj_t pin_irq_obj[16] = {
     {{&pin_irq_type}, 0},
     {{&pin_irq_type}, 1},
     {{&pin_irq_type}, 2},
@@ -486,14 +490,14 @@ STATIC const pin_irq_obj_t pin_irq_obj[16] = {
     {{&pin_irq_type}, 15},
 };
 
-STATIC mp_obj_t pin_irq_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
+static mp_obj_t pin_irq_call(mp_obj_t self_in, size_t n_args, size_t n_kw, const mp_obj_t *args) {
     pin_irq_obj_t *self = self_in;
     mp_arg_check_num(n_args, n_kw, 0, 0, false);
     pin_intr_handler_part2(1 << self->phys_port);
     return mp_const_none;
 }
 
-STATIC mp_obj_t pin_irq_trigger(size_t n_args, const mp_obj_t *args) {
+static mp_obj_t pin_irq_trigger(size_t n_args, const mp_obj_t *args) {
     pin_irq_obj_t *self = args[0];
     uint32_t orig_trig = GET_TRIGGER(self->phys_port);
     if (n_args == 2) {
@@ -503,15 +507,15 @@ STATIC mp_obj_t pin_irq_trigger(size_t n_args, const mp_obj_t *args) {
     // return original trigger value
     return MP_OBJ_NEW_SMALL_INT(orig_trig);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_irq_trigger_obj, 1, 2, pin_irq_trigger);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_irq_trigger_obj, 1, 2, pin_irq_trigger);
 
-STATIC const mp_rom_map_elem_t pin_irq_locals_dict_table[] = {
+static const mp_rom_map_elem_t pin_irq_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_trigger),  MP_ROM_PTR(&pin_irq_trigger_obj) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(pin_irq_locals_dict, pin_irq_locals_dict_table);
+static MP_DEFINE_CONST_DICT(pin_irq_locals_dict, pin_irq_locals_dict_table);
 
-STATIC MP_DEFINE_CONST_OBJ_TYPE(
+static MP_DEFINE_CONST_OBJ_TYPE(
     pin_irq_type,
     MP_QSTR_IRQ,
     MP_TYPE_FLAG_NONE,
